@@ -6,7 +6,7 @@ from pathlib import Path
 
 from mercury_engine_data_structures.file_tree_editor import OutputFormat
 
-from open_dread_rando import elevator, lua_util
+from open_dread_rando import elevator, lua_util, game_patches
 from open_dread_rando.cosmetic_patches import apply_cosmetic_patches
 from open_dread_rando.exefs import include_depackager, patch_exefs
 from open_dread_rando.logger import LOG
@@ -146,6 +146,9 @@ def patch(input_path: Path, output_path: Path, configuration: dict):
     if "cosmetic_patches" in configuration:
         apply_cosmetic_patches(editor, configuration["cosmetic_patches"])
 
+    # Specific game patches
+    game_patches.apply_game_patches(editor, configuration.get("game_patches", {}))
+
     out_romfs, out_exefs, exefs_patches = output_paths_for_compatibility(
         output_path,
         configuration["mod_compatibility"],
